@@ -191,4 +191,6 @@ __all__ = [
     'get_transfer_source_response',
     'create_sub_merchant_request',
     'update_subscription_due_days_request',
+    'create_checkout_pix_payment_request',
+    'get_checkout_pix_payment_response',
 ]
\ No newline at end of file
